===================
modi-helper-scripts
===================

.. image:: https://readthedocs.org/projects/modi-helper-scripts/badge/?version=latest
    :target: https://modi-helper-scripts.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

A set of helper scripts that can be used on MODI to setup environemnts and execute jobs.
